@@ -169,7 +169,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
      * @param parent The parent of the dialog.
      * @param flags  The widget flags passed to the QDialog constructor
      */
-    explicit KDialog( QWidget *parent = 0, Qt::WFlags flags = 0 );
+    explicit KDialog( QWidget *parent = 0, Qt::WindowFlags flags = 0 );
 
     /**
      * Destroys the dialog.
@@ -851,7 +851,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
     void updateGeometry();
 
     protected:
-        KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WFlags flags = 0);
+        KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WindowFlags flags = 0);
         KDialogPrivate *const d_ptr;
 
     private:
